@@ -1,7 +1,7 @@
 """Sending Roundup-specific mail over SMTP.
 """
 __docformat__ = 'restructuredtext'
-# $Id$
+# $Id: mailer.py,v 1.22 2008/07/21 01:44:58 richard Exp $
 
 import time, quopri, os, socket, smtplib, re, sys, traceback
 
@@ -33,8 +33,13 @@ class Mailer:
 
         # set timezone so that things like formatdate(localtime=True)
         # use the configured timezone
-        os.environ['TZ'] = get_timezone(self.config.TIMEZONE).tzname(None)
-        time.tzset()
+        # apparently tzset doesn't exist in python under Windows, my bad.
+        # my pathetic attempts at googling a Windows-solution failed
+        # so if you're on Windows your mail won't use your configured
+        # timezone.
+        if hasattr(time, 'tzset'):
+            os.environ['TZ'] = get_timezone(self.config.TIMEZONE).tzname(None)
+            time.tzset()
 
     def get_standard_message(self, to, subject, author=None):
         '''Form a standard email message from Roundup.
@@ -68,6 +73,9 @@ class Mailer:
         writer.addheader('From', author)
         writer.addheader('Date', formatdate(localtime=True))
 
+        # add a Precedence header so autoresponders ignore us
+        writer.addheader('Precedence', 'bulk')
+
         # Add a unique Roundup header to help filtering
         writer.addheader('X-Roundup-Name', encode_header(tracker_name,
             charset))
