@@ -16,7 +16,7 @@ from __future__ import nested_scopes
 # BASIS, AND THERE IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
 # SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 #
-# $Id$
+# $Id: roundupdb.py,v 1.139 2008/08/07 06:31:16 richard Exp $
 
 """Extending hyperdb with types specific to issue-tracking.
 """
@@ -422,7 +422,9 @@ class IssueClass:
                 # Default the reply to the first message
                 msgs = self.get(nodeid, 'messages')
                 # Assume messages are sorted by increasing message number here
-                if msgs[0] != nodeid:
+                # If the issue is just being created, and the submitter didn't
+                # provide a message, then msgs will be empty.
+                if msgs and msgs[0] != nodeid:
                     inreplyto = messages.get(msgs[0], 'messageid')
                     if inreplyto:
                         writer.addheader('In-Reply-To', inreplyto)
