@@ -14,7 +14,11 @@
 # BASIS, AND THERE IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
 # SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 # 
-# $Id$
+# $Id: roundup_admin.py,v 1.6 2004/02/11 23:55:10 richard Exp $
+
+"""Command-line script stub that calls the roundup.admin functions.
+"""
+__docformat__ = 'restructuredtext'
 
 # python version check
 from roundup import version_check
