@@ -8,7 +8,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #
-# $Id$
+# $Id: test_mailgw.py,v 1.96 2008/08/19 01:40:59 richard Exp $
 
 # TODO: test bcc
 
@@ -39,6 +39,11 @@ class DiffHelper:
     def compareMessages(self, new, old):
         """Compare messages for semantic equivalence."""
         new, old = Message(new), Message(old)
+
+        # all Roundup-generated messages have "Precedence: bulk"
+        old['Precedence'] = 'bulk'
+
+        # don't try to compare the date
         del new['date'], old['date']
 
         if not new == old:
@@ -48,10 +53,10 @@ class DiffHelper:
                 if key.lower() == 'x-roundup-version':
                     # version changes constantly, so handle it specially
                     if new[key] != __version__:
-                        res.append('  %s: %s != %s' % (key, __version__,
+                        res.append('  %s: %r != %r' % (key, __version__,
                             new[key]))
                 elif new.get(key, '') != old.get(key, ''):
-                    res.append('  %s: %s != %s' % (key, old.get(key, ''),
+                    res.append('  %s: %r != %r' % (key, old.get(key, ''),
                         new.get(key, '')))
 
             body_diff = self.compareStrings(new.fp.read(), old.fp.read())
@@ -344,9 +349,7 @@ Roundup issue tracker <issue_tracker@your.tracker.email.domain.example>
 _______________________________________________________________________
 ''')
 
-    multipart_msg = '''Content-Type: text/plain;
-  charset="iso-8859-1"
-From: mary <mary@test.test>
+    multipart_msg = '''From: mary <mary@test.test>
 To: issue_tracker@your.tracker.email.domain.example
 Message-Id: <followup_dummy_id>
 In-Reply-To: <dummy_test_message_id>
@@ -679,7 +682,10 @@ Subject: Re: Testing...
 
 This is a followup
 '''), nodeid)
-        # now try a longer interval
+
+
+    def testFollowupTitleMatchInterval(self):
+        nodeid = self.doNewIssue()
         self.db.config.MAILGW_SUBJECT_CONTENT_MATCH = 'creation +1d'
         self.assertEqual(self._handle_mail('''Content-Type: text/plain;
   charset="iso-8859-1"
